#!/bin/sh

#	d.rast.leg.sh	(GRASS Shell Script)
#
# displays a raster map and its legend on a graphics window. 
#
# Usage: 	d.rast.leg.sh
#	or	d.rast.leg.sh help
#	or	d.rast.leg.sh rast_map [num_of_lines]
#
# Description:	d.rast.leg.sh clears the entire screen, divides it into a main
#		(left) and a minor (right) frames, and then display a raster 
#		map in the main frame and the map legend in the minor frame.
#		The user can run the program interactively or 
#		non-interactively.
#
# Parameters: 	rast_map 	A raster map to be displayed.
#
#	 	num_of_lines 	Number of lines to appear in the legend. 
#				If this number is not given, the legend frame 
#				will display as many lines as number of 
#				categories in the map, otherwise, it will
#				display the first num_of_lines minus 1  
#				categories with the rest being truncated. 
# 
# Note:		The user may adjust the num_of_lines parameter or the size of 
#		graphics window to get an appropriate result.
#
# See also:	d.rast, d.legend.
#
# Jianping Xu and Scott Madry, Rutgers University.
# October 19, 1993
##############################################################################

if [ $# -gt 0 ] 
then
    if [ $1 = "help" ]
    then
	echo 
    	echo "Usage:	d.rast.leg.sh"
    	echo "    or	d.rast.leg.sh help"
    	echo "    or	d.rast.leg.sh rast_map [num_of_lines]"
    	echo
    	exit 1
    fi
fi

if [ $# -gt 2 ]
then
    echo 
    echo "Usage:	d.rast.leg.sh"
    echo "    or	d.rast.leg.sh help"
    echo "    or	d.rast.leg.sh rast_map [num_of_lines]"
    echo
    exit 1
fi

d.frame -e

if [ $# = 0 ]
then
    d.frame -s at=0,100,0,65
    d.rast
    echo
    echo "Please enter the name of the raster file again!"
    d.frame -s at=0,100,65,100
    d.legend 
    d.frame -s at=0,100,0,65
else
    if [ $# = 1 ]
    then
	d.frame -s at=0,100,0,65
    	d.rast $1
    	d.frame -s at=0,100,65,100
    	d.legend $1
    	d.frame -s at=0,100,0,65
    else
	d.frame -s at=0,100,0,65
    	d.rast $1
    	d.frame -s at=0,100,65,100
    	d.legend $1 lines=$2
    	d.frame -s at=0,100,0,65
    fi
fi
